@@ -35,13 +35,30 @@ pygnome_add_defined_constants (PyObject *dict)
 	PyDict_SetItemString (dict, "PARAM_APP_DATADIR", PyString_FromString (GNOME_PARAM_APP_DATADIR));
 	PyDict_SetItemString (dict, "PARAM_APP_LIBDIR", PyString_FromString (GNOME_PARAM_APP_LIBDIR));
 	PyDict_SetItemString (dict, "PARAM_HUMAN_READABLE_NAME", PyString_FromString (GNOME_PARAM_HUMAN_READABLE_NAME));
-	PyDict_SetItemString (dict, "PARAM_GNOME_PATH", PyString_FromString (GNOME_PARAM_GNOME_PATH));		
+	PyDict_SetItemString (dict, "PARAM_GNOME_PATH", PyString_FromString (GNOME_PARAM_GNOME_PATH));
+
+	PyDict_SetItemString (dict, "POPT_ARGFLAG_OR", PyInt_FromLong (POPT_ARGFLAG_OR));
+	PyDict_SetItemString (dict, "POPT_ARGFLAG_AND", PyInt_FromLong (POPT_ARGFLAG_AND));
+	PyDict_SetItemString (dict, "POPT_ARGFLAG_XOR", PyInt_FromLong (POPT_ARGFLAG_XOR));
+	PyDict_SetItemString (dict, "POPT_ARGFLAG_NOT", PyInt_FromLong (POPT_ARGFLAG_NOT));
+	PyDict_SetItemString (dict, "POPT_ARGFLAG_NOR", PyInt_FromLong (POPT_ARGFLAG_NOR));
+	PyDict_SetItemString (dict, "POPT_ARGFLAG_NAND", PyInt_FromLong (POPT_ARGFLAG_NAND));
+	PyDict_SetItemString (dict, "POPT_ARGFLAG_LOGICALOPS", PyInt_FromLong (POPT_ARGFLAG_LOGICALOPS));
+	PyDict_SetItemString (dict, "POPT_ARGFLAG_ONEDASH", PyInt_FromLong (POPT_ARGFLAG_ONEDASH));
+	PyDict_SetItemString (dict, "POPT_ARGFLAG_DOC_HIDDEN", PyInt_FromLong (POPT_ARGFLAG_DOC_HIDDEN));
+	PyDict_SetItemString (dict, "POPT_ARGFLAG_STRIP", PyInt_FromLong (POPT_ARGFLAG_STRIP));
+	PyDict_SetItemString (dict, "POPT_ARGFLAG_OPTIONAL", PyInt_FromLong (POPT_ARGFLAG_OPTIONAL));
+	PyDict_SetItemString (dict, "POPT_ARGFLAG_SHOW_DEFAULT", PyInt_FromLong (POPT_ARGFLAG_SHOW_DEFAULT));
+	PyDict_SetItemString (dict, "POPT_CONTEXT_NO_EXEC", PyInt_FromLong (POPT_CONTEXT_NO_EXEC));
+	PyDict_SetItemString (dict, "POPT_CONTEXT_KEEP_FIRST", PyInt_FromLong (POPT_CONTEXT_KEEP_FIRST));
+	PyDict_SetItemString (dict, "POPT_CONTEXT_POSIXMEHARDER", PyInt_FromLong (POPT_CONTEXT_POSIXMEHARDER));
+	PyDict_SetItemString (dict, "POPT_CONTEXT_ARG_OPTS", PyInt_FromLong (POPT_CONTEXT_ARG_OPTS));
 }
 
 DL_EXPORT(void)
 init_gnome (void)
 {
-    PyObject *m, *d;
+    PyObject *m, *d, *tuple;
 	
     init_pygobject ();
     
@@ -51,6 +68,12 @@ init_gnome (void)
     pygnome_register_classes (d);
     pygnome_add_constants (m, "GNOME_");
     pygnome_add_defined_constants (d);
+
+    /* gnome-python version */
+    tuple = Py_BuildValue("(iii)", GNOME_PYTHON_MAJOR_VERSION, GNOME_PYTHON_MINOR_VERSION,
+                          GNOME_PYTHON_MICRO_VERSION);
+    PyDict_SetItemString(d, "gnome_python_version", tuple);
+    Py_DECREF(tuple);
 	
     if (!gnome_program_module_registered (LIBGNOME_MODULE))
 	gnome_program_module_register (LIBGNOME_MODULE);
