@@ -31,8 +31,4 @@ initui (void)
     PyDict_SetItemString(d, "PAD_BIG", PyInt_FromLong(GNOME_PAD_BIG));
         
     gnome_program_module_register(LIBGNOMEUI_MODULE);
-	
-    if (PyErr_Occurred ()) {
-	Py_FatalError ("can't initialise module gnome.ui");
-    }
 }
